# FORMULA LLM - OpenAI Explanation and Repair

### Requirements
```bash
python >= 3.10
dotnet 6.0
```

### Install and Set Env
```bash
dotnet tool install --global VUISIS.Formula.<x64|ARM64> 

Set the environment variable OPENAI_API_KEY before running.
```